# Meta Model Configuration
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/meta-model-configuration#overview)
  * [Best Practices](https://help.sap.com/docs/leanix/ea/meta-model-configuration#best-practices)
  * [Configuring a Fact Sheet](https://help.sap.com/docs/leanix/ea/meta-model-configuration#configuring-a-fact-sheet)
  * [Fact Sheet Settings](https://help.sap.com/docs/leanix/ea/meta-model-configuration#fact-sheet-settings)
  * [Fact Sheet Description](https://help.sap.com/docs/leanix/ea/meta-model-configuration#fact-sheet-description)
  * [Fact Sheet Structure](https://help.sap.com/docs/leanix/ea/meta-model-configuration#fact-sheet-structure)
  * [Adding Sections and Subsections](https://help.sap.com/docs/leanix/ea/meta-model-configuration#adding-sections-and-subsections)
  * [Reordering Sections and Subsections](https://help.sap.com/docs/leanix/ea/meta-model-configuration#reordering-sections-and-subsections)


View all
Configure the meta model to adjust it to your requirements.
